==> commons-model-4.0.3-sources.jar: com/epam/ta/reportportal/ws/model/role/SaveRoleRQ.java <==
/*
 * Copyright 2016 EPAM Systems
 * 
 * 
 * This file is part of EPAM Report Portal.
 * https://github.com/reportportal/commons-model
 * 
 * Report Portal is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Report Portal is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Report Portal.  If not, see <http://www.gnu.org/licenses/>.
 */ 
 
package com.epam.ta.reportportal.ws.model.role;

import javax.validation.constraints.NotNull;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * 
 * @author Siarhei_Kharlanau
 * 
 */
@JsonInclude(Include.NON_NULL)
public class SaveRoleRQ {

	@NotNull
	@JsonProperty(value = "role_name", required = true)
	private String roleName;

	@NotNull
	@JsonProperty(value = "permissions", required = true)
	private String permissions;

	public String getRoleName() {
		return roleName;
	}

	public void setRoleName(String roleName) {
		this.roleName = roleName;
	}

	public String getPermissions() {
		return permissions;
	}

	public void setPermissions(String permissions) {
		this.permissions = permissions;
	}

	@Override
	public String toString() {
		final StringBuilder sb = new StringBuilder("SaveRoleRQ{");
		sb.append("roleName='").append(roleName).append('\'');
		sb.append(", permissions='").append(permissions).append('\'');
		sb.append('}');
		return sb.toString();
	}

}

==> commons-model-5.0.0-sources.jar: com/epam/ta/reportportal/ws/model/role/SaveRoleRQ.java <==
/*
 * Copyright 2019 EPAM Systems
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
 
package com.epam.ta.reportportal.ws.model.role;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;

import javax.validation.constraints.NotNull;

/**
 * 
 * @author Siarhei_Kharlanau
 * 
 */
@JsonInclude(Include.NON_NULL)
public class SaveRoleRQ {

	@NotNull
	@JsonProperty(value = "roleName", required = true)
	private String roleName;

	@NotNull
	@JsonProperty(value = "permissions", required = true)
	private String permissions;

	public String getRoleName() {
		return roleName;
	}

	public void setRoleName(String roleName) {
		this.roleName = roleName;
	}

	public String getPermissions() {
		return permissions;
	}

	public void setPermissions(String permissions) {
		this.permissions = permissions;
	}

	@Override
	public String toString() {
		final StringBuilder sb = new StringBuilder("SaveRoleRQ{");
		sb.append("roleName='").append(roleName).append('\'');
		sb.append(", permissions='").append(permissions).append('\'');
		sb.append('}');
		return sb.toString();
	}

}
